..
    SPDX-FileCopyrightText: 2024 Alec Delaney, for Adafruit Industries
    SPDX-License-Identifier: MIT

Documentation
=============

Documentation is generated by Sphinx and a number of Sphinx extensions.

This documentation is pushed with every ``git push`` using a repository
webhook to ReadTheDocs so others can view it online.

You can manually test building the documentation during development by
running ``make docs``.
